@@ -38,5 +38,5 @@ ScriptInfo::ScriptInfo()
 	ScriptType = "V4.00";
 	Collisions = "Normal";
 	Timer = "100";
-	WarpStyle = "0";
+	WrapStyle = "0";
 }
