@@ -41,7 +41,6 @@
 #include <gdk/gdkkeysyms.h>
 
 #include "SubtitleEditor.h"
-#include "SpellDialog.h"
 
 #include <config.h>
 #include "utility.h"
@@ -53,8 +52,11 @@
 #include "DialogPreferences.h"
 #include "DialogFind.h"
 
+#include "DialogSpellChecking.h"
+
 #include "SubtitleSystem.h"
 
+
 namespace SE
 {
 ISubtitleEditor* getInstance()
@@ -68,16 +70,13 @@ SubtitleEditor* SubtitleEditor::m_static_subtitleEditor = NULL;
 
 SubtitleEditor* SubtitleEditor::getInstance()
 {
-	//debug_msg("getInstance()");
-
 	if(m_static_subtitleEditor == NULL)
 	{
-		debug_msg("getInstance > new SubtitleEditor");
+		se_debug(SE_DEBUG_APP);
+
 		Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(get_share_dir("subtitleeditor.glade"));
 
 		refXml->get_widget_derived("window-subtitleeditor", m_static_subtitleEditor);
-		
-	//m_static_subtitleEditor = new SubtitleEditor();
 	}
 
 	return m_static_subtitleEditor;
@@ -91,14 +90,15 @@ SubtitleEditor* SubtitleEditor::getInstance()
 SubtitleEditor::SubtitleEditor(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
 :Gtk::Window(cobject), m_treeviewSubtitle(NULL)
 {
+	se_debug(SE_DEBUG_APP);
+
 	m_static_subtitleEditor = this;
 
-	debug_msg("SubtitleEditor::SubtitleEditor > start");
 	
 	m_dialogFindAndReplace = NULL;
 	m_dialogScale = NULL;
 	m_dialogChangeFPS = NULL;
-
+	m_dialogMoveSubtitles = NULL;
 
 
 	Gtk::VBox* vbox = NULL;
@@ -112,21 +112,17 @@ SubtitleEditor::SubtitleEditor(BaseObjectType* cobject, const Glib::RefPtr<Gnome
 	vbox->pack_start(*menubar, false,false);
 	vbox->reorder_child(*menubar, 0);
 
-	debug_msg("SubtitleEditor::SubtitleEditor > load AccelMap");
+	se_debug_message(SE_DEBUG_APP, "load AccelMap");
 
 	// on va chercher la configuration clavier
 	Glib::ustring path_se_accelmap = Glib::build_filename(Glib::build_filename(Glib::get_home_dir(), ".subtitleeditor"), "accelmap");
 	
 	Gtk::AccelMap::load(path_se_accelmap);
 
+	//config
+	se_debug_message(SE_DEBUG_APP, "load Config");
 
-	debug_msg("SubtitleEditor::SubtitleEditor > loadCfg");
-
-	// config
 	loadCfg();
-	//
-	debug_msg("SubtitleEditor::SubtitleEditor > finish");
-
 }
 
 /*
@@ -134,13 +130,14 @@ SubtitleEditor::SubtitleEditor(BaseObjectType* cobject, const Glib::RefPtr<Gnome
  */
 SubtitleEditor::~SubtitleEditor()
 {
-	debug_msg("SubtitleEditor::~SubtitleEditor > start");
+	se_debug(SE_DEBUG_APP);
+
+
+	se_debug_message(SE_DEBUG_APP, "Save config");
 
-	debug_msg("SubtitleEditor::~SubtitleEditor > saveCfg");
-	
 	saveCfg();
 
-	debug_msg("SubtitleEditor::~SubtitleEditor > save .subtitleeditor");
+	se_debug_message(SE_DEBUG_APP, "save ~/.subtitleeditor");
 
 	// on sauvegarde la configuration clavier
 	Glib::ustring path_se = Glib::build_filename(Glib::get_home_dir(), ".subtitleeditor");
@@ -148,13 +145,13 @@ SubtitleEditor::~SubtitleEditor()
 
 	Gtk::AccelMap::save(path_se_accelmap);
 
-	debug_msg("SubtitleEditor::~SubtitleEditor > delete dialog");
 
+	se_debug_message(SE_DEBUG_APP, "Delete dialog");
+
+	delete m_dialogMoveSubtitles;
 	delete m_dialogFindAndReplace;
 	delete m_dialogScale;
 	delete m_dialogChangeFPS;
-
-	debug_msg("SubtitleEditor::~SubtitleEditor > finish");
 }
 
 /*
@@ -265,7 +262,7 @@ void SubtitleEditor::createMenuBar()
  */
 void SubtitleEditor::on_new_subtitle()
 {
-	debug_msg("SubtitleEditor::on_new_subtitle");
+	se_debug(SE_DEBUG_APP);
 
 	getDocument()->clear();
 	setStatusbar(_("New Document"));
@@ -276,7 +273,7 @@ void SubtitleEditor::on_new_subtitle()
  */
 void SubtitleEditor::on_quit()
 {
-	debug_msg("SubtitleEditor::on_quit");
+	se_debug(SE_DEBUG_APP);
 
 	//Gtk::MessageDialog dialog(*this, "Are you sure ?", false, Gtk::MESSAGE_QUESTION , Gtk::BUTTONS_YES_NO ,true);
 	//if(dialog.run() == Gtk::RESPONSE_YES)
@@ -288,7 +285,7 @@ void SubtitleEditor::on_quit()
  */
 void SubtitleEditor::on_open_subtitle()
 {
-	debug_msg("SubtitleEditor::on_open_subtitle");
+	se_debug(SE_DEBUG_APP);
 
 	Glib::ustring file ;
 	m_dialogOpenSubtitle.show();
@@ -313,7 +310,7 @@ void SubtitleEditor::on_open_subtitle()
  */
 void SubtitleEditor::on_open_media_for_timing()
 {
-	debug_msg("SubtitleEditor::on_open_media_for_timing");
+	se_debug(SE_DEBUG_APP);
 
 	DialogOpenMedia	dialog;
 	if(dialog.run() == Gtk::RESPONSE_OK)
@@ -337,6 +334,8 @@ void SubtitleEditor::on_open_media_for_timing()
  */
 void SubtitleEditor::on_save_waveform()
 {
+	se_debug(SE_DEBUG_APP);
+
 	DialogSaveWaveform	dialog;
 	if(dialog.run() == Gtk::RESPONSE_OK)
 	{
@@ -360,6 +359,8 @@ void SubtitleEditor::on_save_waveform()
  */
 void SubtitleEditor::on_timing_play_previous_subtitle()
 {
+	se_debug(SE_DEBUG_APP);
+
 	Gtk::TreeIter iter = m_treeviewSubtitle->getSelected();
 	if(!iter)
 		iter = getDocument()->get_subtitle_model()->getFirst();
@@ -377,6 +378,8 @@ void SubtitleEditor::on_timing_play_previous_subtitle()
  */
 void SubtitleEditor::on_timing_play_current_subtitle()
 {
+	se_debug(SE_DEBUG_APP);
+
 	Gtk::TreeIter iter = m_treeviewSubtitle->getSelected();
 	
 	if(!iter)
@@ -391,6 +394,8 @@ void SubtitleEditor::on_timing_play_current_subtitle()
  */
 void SubtitleEditor::on_timing_play_next_subtitle()
 {
+	se_debug(SE_DEBUG_APP);
+
 	Gtk::TreeIter iter = m_treeviewSubtitle->getSelected();
 	if(!iter)
 		iter = getDocument()->get_subtitle_model()->getFirst();
@@ -408,6 +413,8 @@ void SubtitleEditor::on_timing_play_next_subtitle()
  */
 void SubtitleEditor::on_timing_stop()
 {
+	se_debug(SE_DEBUG_APP);
+
 	m_timingSystem->stop();
 }
 
@@ -416,12 +423,14 @@ void SubtitleEditor::on_timing_stop()
  */
 void SubtitleEditor::on_timing_play_previous_second()
 {
-	Gtk::TreeIter iter = m_treeviewSubtitle->getSelected();
-	if(!iter)
+	se_debug(SE_DEBUG_APP);
+
+	SubtitleModifier subtitle(m_treeviewSubtitle->getSelected());
+	if(!subtitle)
 		return;
 
-	SubtitleTime time((*iter)[m_column.start]);
-	
+	SubtitleTime time = subtitle.get_start();
+
 	m_timingSystem->play_subtitle(time - SubtitleTime(0,0,1,0), time);
 }
 
@@ -430,11 +439,13 @@ void SubtitleEditor::on_timing_play_previous_second()
  */
 void SubtitleEditor::on_timing_play_first_second()
 {
-	Gtk::TreeIter iter = m_treeviewSubtitle->getSelected();
-	if(!iter)
+	se_debug(SE_DEBUG_APP);
+
+	SubtitleModifier subtitle(m_treeviewSubtitle->getSelected());
+	if(!subtitle)
 		return;
 
-	SubtitleTime time((*iter)[m_column.start]);
+	SubtitleTime time = subtitle.get_start();
 	
 	m_timingSystem->play_subtitle(time, time + SubtitleTime(0,0,1,0));
 }
@@ -444,11 +455,13 @@ void SubtitleEditor::on_timing_play_first_second()
  */
 void SubtitleEditor::on_timing_play_last_second()
 {
-	Gtk::TreeIter iter = m_treeviewSubtitle->getSelected();
-	if(!iter)
+	se_debug(SE_DEBUG_APP);
+
+	SubtitleModifier subtitle(m_treeviewSubtitle->getSelected());
+	if(!subtitle)
 		return;
 
-	SubtitleTime time((*iter)[m_column.end]);
+	SubtitleTime time = subtitle.get_end();
 	
 	m_timingSystem->play_subtitle(time - SubtitleTime(0,0,1,0), time);
 }
@@ -458,11 +471,13 @@ void SubtitleEditor::on_timing_play_last_second()
  */
 void SubtitleEditor::on_timing_play_next_second()
 {
-	Gtk::TreeIter iter = m_treeviewSubtitle->getSelected();
-	if(!iter)
+	se_debug(SE_DEBUG_APP);
+
+	SubtitleModifier subtitle(m_treeviewSubtitle->getSelected());
+	if(!subtitle)
 		return;
 	
-	SubtitleTime time((*iter)[m_column.end]);
+	SubtitleTime time = subtitle.get_end();
 	
 	m_timingSystem->play_subtitle(time, time + SubtitleTime(0,0,1,0));
 }
@@ -474,7 +489,7 @@ void SubtitleEditor::on_timing_play_next_second()
  */
 void SubtitleEditor::on_open_movie()
 {
-	debug_msg("SubtitleEditor::on_open_movie");
+	se_debug(SE_DEBUG_APP);
 
 	m_dialogOpenMovie.show();
 	if(m_dialogOpenMovie.run() == Gtk::RESPONSE_OK)
@@ -486,25 +501,12 @@ void SubtitleEditor::on_open_movie()
 	m_dialogOpenMovie.hide();
 }
 
-/*
- *
- */
-void SubtitleEditor::on_video_properties()
-{
-	DialogVideoProperties *m_dialogVideoProperties = NULL;
-	create_dialog("dialog-video-properties", &m_dialogVideoProperties);
-
-	m_dialogVideoProperties->execute();
-
-	delete m_dialogVideoProperties;
-}
-
 /*
  *
  */
 void SubtitleEditor::on_save_subtitle()
 {
-	debug_msg("SubtitleEditor::on_save_subtitle");
+	se_debug(SE_DEBUG_APP);
 
 	if(!getDocument()->filenameDocument.empty())
 	{
@@ -528,7 +530,7 @@ void SubtitleEditor::on_save_subtitle()
  */
 void SubtitleEditor::on_save_as_subtitle()
 {
-	debug_msg("SubtitleEditor::on_save_as_subtitle");
+	se_debug(SE_DEBUG_APP);
 
 	m_dialogSaveSubtitle.show();
 	if(m_dialogSaveSubtitle.run() == Gtk::RESPONSE_OK)
@@ -550,7 +552,7 @@ void SubtitleEditor::on_save_as_subtitle()
  */
 void SubtitleEditor::on_import_text()
 {
-	debug_msg("SubtitleEditor::on_import_text");
+	se_debug(SE_DEBUG_APP);
 
 	m_dialogImportText.show();
 	if(m_dialogImportText.run() == Gtk::RESPONSE_OK)
@@ -573,7 +575,7 @@ void SubtitleEditor::on_import_text()
  */
 void SubtitleEditor::on_export_text()
 {
-	debug_msg("SubtitleEditor::on_export_text");
+	se_debug(SE_DEBUG_APP);
 
 	m_dialogExportText.show();
 	if(m_dialogExportText.run() == Gtk::RESPONSE_OK)
@@ -597,7 +599,7 @@ void SubtitleEditor::on_export_text()
  */
 void SubtitleEditor::on_properties()
 {
-	debug_msg("SubtitleEditor::on_properties");
+	se_debug(SE_DEBUG_APP);
 
 	DialogScriptProperties * dialog = NULL;
 	
@@ -613,37 +615,38 @@ void SubtitleEditor::on_properties()
  */
 void SubtitleEditor::on_play_movie()
 {
-	debug_msg("SubtitleEditor::on_play_movie > start");
+	se_debug(SE_DEBUG_APP);
 
 	Document *doc = getDocument();
-
+/*
 	if(doc->filenameDocument.empty())
 	{
-		debug_msg("SubtitleEditor::on_play_movie > filenameDocument == NULL");
+		se_debug_message(SE_DEBUG_APP, "filenameDocument == NULL");
 		setStatusbar(_("I can't play movie"));
 		return;
 	}
-
+*/
 	if(doc->m_uriMovie.empty())
 	{
-		debug_msg("SubtitleEditor::on_play_movie > m_uriMovie == NULL");
+		se_debug_message(SE_DEBUG_APP, "m_uriMovie == NULL");
 		setStatusbar(_("I can't play movie. Please select a movie"));
 		
 		on_open_movie();
 		return;
 	}
 
-	
-	debug_msg("SubtitleEditor::on_play_movie > save tmp subtitle");
 
 	Glib::ustring subtitle_name = "subtitle." + SubtitleSystem::getInstance().get_extension(doc->getFormat());
+
 	// on ecrit un fichier tmp pour les sous titres..
 	Glib::ustring subtitle_file = Glib::build_filename(Glib::get_tmp_dir(), subtitle_name);
 
+	se_debug_message(SE_DEBUG_APP, "Save temp subtitle <%s>", subtitle_file.c_str());
+
 	getDocument()->save(subtitle_file, doc->getFormat(), "", false);
 	
 	
-	debug_msg("SubtitleEditor::on_play_movie > select subtitle for start movie");
+	se_debug_message(SE_DEBUG_APP, "Select subtitle for start movie");
 
 	long position = 0;
 
@@ -658,7 +661,7 @@ void SubtitleEditor::on_play_movie()
 		position = time.hours*3600 + time.mins*60 + time.secs;
 	}
 
-	debug_msg("SubtitleEditor::on_play_movie > create cmd line");
+	se_debug_message(SE_DEBUG_APP, "Create cmd line");
 
 	/*
 	 *	#subtitle_file
@@ -691,6 +694,8 @@ void SubtitleEditor::on_play_movie()
 
 			std::cout << std::endl << cmd << std::endl << std::endl;
 
+			se_debug_message(SE_DEBUG_APP, "exec: %s", cmd.c_str());
+
 			Glib::spawn_command_line_async(cmd);
 		}
 	}
@@ -698,144 +703,203 @@ void SubtitleEditor::on_play_movie()
 	{
 		// error
 	}
-	debug_msg("SubtitleEditor::on_play_movie > finish");
 }
 
 /*
  *
  */
-void SubtitleEditor::on_move_subtitle()
+void SubtitleEditor::on_move_subtitles()
 {
-	debug_msg("SubtitleEditor::on_move_subtitle");
+	se_debug(SE_DEBUG_APP);
 
-	Gtk::TreeIter iter = m_treeviewSubtitle->getSelected();
-	if(!iter)
-		return;
+	create_dialog("dialog-move-subtitles", &m_dialogMoveSubtitles);
 
-	SubtitleColumnRecorder m_column;
-	
-	SubtitleTime start((*iter)[m_column.start]);
+	m_dialogMoveSubtitles->show();
 
-	m_dialogMoveSubtitle.set_value(start);
-	m_dialogMoveSubtitle.show();
+	m_dialogMoveSubtitles->execute();
 
-	if(m_dialogMoveSubtitle.run() == Gtk::RESPONSE_OK)
+	m_dialogMoveSubtitles->hide();
+}
+
+/*
+ *
+ */
+void SubtitleEditor::on_add_100_ms()
+{
+	se_debug(SE_DEBUG_APP);
+
+	Glib::RefPtr<Gtk::TreeSelection> selection = getSubtitleView()->get_selection();
+
+	std::vector<Gtk::TreeModel::Path> rows = selection->get_selected_rows();
+
+	if(rows.size() > 0)
 	{
-		SubtitleTime diff = m_dialogMoveSubtitle.get_value() - start;
-		getDocument()->m_subtitleModel->move_all((*iter)[m_column.num], diff.totalmsecs);
+		SubtitleTime time(0,0,0,100);
+
+		// for all selection
+		for(unsigned int i=0; i<rows.size(); ++i)
+		{
+			// get iter
+			SubtitleModifier subtitle(getDocument()->get_subtitle_model()->get_iter(rows[i]));
+			// add 100 ms
+			subtitle.set_start( subtitle.get_start() + time);
+			subtitle.set_end( subtitle.get_end() + time);
+			// emit signal changed
+			Signal::getInstance().subtitle_time_changed(subtitle.get_iter());
+		}
 	}
-	m_dialogMoveSubtitle.hide();
 }
 
-void SubtitleEditor::on_move_subtitle_start_plus()
+/*
+ *
+ */
+void SubtitleEditor::on_remove_100_ms()
 {
-	Gtk::TreeIter iter = m_treeviewSubtitle->getSelected();
-	if(!iter)
-		return;
+	se_debug(SE_DEBUG_APP);
 
-	SubtitleColumnRecorder m_column;
-	
-	SubtitleTime start((*iter)[m_column.start]);
-	
-	start = start + SubtitleTime(0,0,0,100);
-	
-	(*iter)[m_column.start] = start.str();
+	Glib::RefPtr<Gtk::TreeSelection> selection = getSubtitleView()->get_selection();
 
-	Signal::getInstance().subtitle_time_changed(iter);
+	std::vector<Gtk::TreeModel::Path> rows = selection->get_selected_rows();
+
+	if(rows.size() > 0)
+	{
+		SubtitleTime time(0,0,0,100);
+
+		// for all selection
+		for(unsigned int i=0; i<rows.size(); ++i)
+		{
+			// get iter
+			SubtitleModifier subtitle(getDocument()->get_subtitle_model()->get_iter(rows[i]));
+			// remove 100 ms
+			subtitle.set_start( subtitle.get_start() - time);
+			subtitle.set_end( subtitle.get_end() - time);
+			// emit signal changed
+			Signal::getInstance().subtitle_time_changed(subtitle.get_iter());
+		}
+	}
 }
 
-void SubtitleEditor::on_move_subtitle_start_minus()
-{
-	Gtk::TreeIter iter = m_treeviewSubtitle->getSelected();
-	if(!iter)
-		return;
-
-	SubtitleColumnRecorder m_column;
-	
-	SubtitleTime start((*iter)[m_column.start]);
-	
-	start = start - SubtitleTime(0,0,0,100);
-	
-	(*iter)[m_column.start] = start.str();
-
-	Signal::getInstance().subtitle_time_changed(iter);
-}
-
-void SubtitleEditor::on_move_subtitle_end_plus()
-{
-	Gtk::TreeIter iter = m_treeviewSubtitle->getSelected();
-	if(!iter)
-		return;
-
-	SubtitleColumnRecorder m_column;
-	
-	SubtitleTime end((*iter)[m_column.end]);
-	
-	end = end + SubtitleTime(0,0,0,100);
-	
-	(*iter)[m_column.end] = end.str();
-
-	Signal::getInstance().subtitle_time_changed(iter);
-}
-
-void SubtitleEditor::on_move_subtitle_end_minus()
-{
-	Gtk::TreeIter iter = m_treeviewSubtitle->getSelected();
-	if(!iter)
-		return;
-
-	SubtitleColumnRecorder m_column;
-	
-	SubtitleTime end((*iter)[m_column.end]);
-	
-	end = end - SubtitleTime(0,0,0,100);
-	
-	(*iter)[m_column.end] = end.str();
-
-	Signal::getInstance().subtitle_time_changed(iter);
-}
 
 
 /*
- * edit le subtitle select
+ *
  */
-void SubtitleEditor::on_edit_subtitle()
+void SubtitleEditor::on_add_100_ms_to_start()
 {
-#warning "fixme > Subtitle"
-/*	
-	Gtk::TreeIter iter = m_treeviewSubtitle->getSelected();
-	if(!iter)
+	se_debug(SE_DEBUG_APP);
+
+	Glib::RefPtr<Gtk::TreeSelection> selection = getSubtitleView()->get_selection();
+
+	std::vector<Gtk::TreeModel::Path> rows = selection->get_selected_rows();
+
+	if(rows.size() > 0)
 	{
-		// si le model est vide alors on cre un par defaut
-		if(getDocument()->m_subtitleModel->getSize() == 0)
+		SubtitleTime time(0,0,0,100);
+
+		// for all selection
+		for(unsigned int i=0; i<rows.size(); ++i)
 		{
-			Gtk::TreeIter it = getDocument()->m_subtitleModel->append();
-			Subtitle sub;
-			getDocument()->m_subtitleModel->refresh(it, sub);
+			// get iter
+			SubtitleModifier subtitle(getDocument()->get_subtitle_model()->get_iter(rows[i]));
+			// add 100 ms
+			subtitle.set_start( subtitle.get_start() + time);
+			// emit signal changed
+			Signal::getInstance().subtitle_time_changed(subtitle.get_iter());
 		}
-		return;
 	}
-
-	SubtitleColumnRecorder m_column;
-	Subtitle select = (*iter)[m_column.subtitle];
-
-	m_dialogEditSubtitle.set_value(select);
-	
-	m_dialogEditSubtitle.show();
-	
-	if(m_dialogEditSubtitle.run() == Gtk::RESPONSE_OK)
-	{
-		select = m_dialogEditSubtitle.get_value();
-		(*iter)[m_column.subtitle] = select;
-		getDocument()->m_subtitleModel->refresh(iter, select);
-	}
-
-	m_dialogEditSubtitle.hide();
-*/
 }
 
+/*
+ *
+ */
+void SubtitleEditor::on_remove_100_ms_to_start()
+{
+	se_debug(SE_DEBUG_APP);
+
+	Glib::RefPtr<Gtk::TreeSelection> selection = getSubtitleView()->get_selection();
+
+	std::vector<Gtk::TreeModel::Path> rows = selection->get_selected_rows();
+
+	if(rows.size() > 0)
+	{
+		SubtitleTime time(0,0,0,100);
+
+		// for all selection
+		for(unsigned int i=0; i<rows.size(); ++i)
+		{
+			// get iter
+			SubtitleModifier subtitle(getDocument()->get_subtitle_model()->get_iter(rows[i]));
+			// remove 100 ms
+			subtitle.set_start( subtitle.get_start() - time);
+			// emit signal changed
+			Signal::getInstance().subtitle_time_changed(subtitle.get_iter());
+		}
+	}
+}
+
+/*
+ *
+ */
+void SubtitleEditor::on_add_100_ms_to_duration()
+{
+	se_debug(SE_DEBUG_APP);
+
+	Glib::RefPtr<Gtk::TreeSelection> selection = getSubtitleView()->get_selection();
+
+	std::vector<Gtk::TreeModel::Path> rows = selection->get_selected_rows();
+
+	if(rows.size() > 0)
+	{
+		SubtitleTime time(0,0,0,100);
+
+		// for all selection
+		for(unsigned int i=0; i<rows.size(); ++i)
+		{
+			// get iter
+			SubtitleModifier subtitle(getDocument()->get_subtitle_model()->get_iter(rows[i]));
+			// remove 100 ms
+			subtitle.set_end( subtitle.get_end() + time);
+			// emit signal changed
+			Signal::getInstance().subtitle_time_changed(subtitle.get_iter());
+		}
+	}
+}
+
+/*
+ *
+ */
+void SubtitleEditor::on_remove_100_ms_to_duration()
+{
+	se_debug(SE_DEBUG_APP);
+
+	Glib::RefPtr<Gtk::TreeSelection> selection = getSubtitleView()->get_selection();
+
+	std::vector<Gtk::TreeModel::Path> rows = selection->get_selected_rows();
+
+	if(rows.size() > 0)
+	{
+		SubtitleTime time(0,0,0,100);
+
+		// for all selection
+		for(unsigned int i=0; i<rows.size(); ++i)
+		{
+			// get iter
+			SubtitleModifier subtitle(getDocument()->get_subtitle_model()->get_iter(rows[i]));
+			// remove 100 ms
+			subtitle.set_end( subtitle.get_end() - time);
+			// emit signal changed
+			Signal::getInstance().subtitle_time_changed(subtitle.get_iter());
+		}
+	}
+}
+
+/*
+ *
+ */
 void SubtitleEditor::on_select_previous_subtitle()
 {
+	se_debug(SE_DEBUG_APP);
+
 	Gtk::TreeIter it = getSubtitleView()->getSelected();
 	if(it)
 	{
@@ -851,8 +915,13 @@ void SubtitleEditor::on_select_previous_subtitle()
 	}
 }
 
+/*
+ *
+ */
 void SubtitleEditor::on_select_next_subtitle()
 {
+	se_debug(SE_DEBUG_APP);
+
 	Gtk::TreeIter it = getSubtitleView()->getSelected();
 	if(it)
 	{
@@ -873,7 +942,7 @@ void SubtitleEditor::on_select_next_subtitle()
  */
 void SubtitleEditor::on_insert_before_subtitle()
 {
-	debug_msg("SubtitleEditor::on_insert_before_subtitle");
+	se_debug(SE_DEBUG_APP);
 
 	Gtk::TreeIter select = m_treeviewSubtitle->getSelected();
 	if(!select)
@@ -887,25 +956,25 @@ void SubtitleEditor::on_insert_before_subtitle()
 		return;
 	}
 
-	SubtitleColumnRecorder m_column;
-
 	SubtitleTime time_start;
-	Gtk::TreeIter prev = getDocument()->m_subtitleModel->find_previous(select);
+	SubtitleModifier prev( getDocument()->m_subtitleModel->find_previous(select));
 	
 	if(prev)
 	{
-		time_start = SubtitleTime((*prev)[m_column.end]);
+		time_start = prev.get_end();
 	}
 
 	// on recupere le temps de depart pour s'en servir comme temps de fin
-	SubtitleTime time_end = SubtitleTime((*select)[m_column.start]);
+	SubtitleTime time_end = SubtitleModifier(*select).get_start();
 	
 	
 	Gtk::TreeIter new_iter = getDocument()->m_subtitleModel->insertBefore(select);
-	m_treeviewSubtitle->select_and_set_cursor(new_iter);
 
-	(*new_iter)[m_column.start]	= time_start.str();
-	(*new_iter)[m_column.end]		= time_end.str();
+	SubtitleModifier ni(new_iter);
+	ni.set_start(time_start);
+	ni.set_end(time_end);
+
+	getSubtitleView()->select_and_set_cursor(new_iter);
 }
 
 /*
@@ -913,7 +982,7 @@ void SubtitleEditor::on_insert_before_subtitle()
  */
 void SubtitleEditor::on_insert_after_subtitle()
 {
-	debug_msg("SubtitleEditor::on_insert_after_subtitle");
+	se_debug(SE_DEBUG_APP);
 
 	Gtk::TreeIter iter_select = m_treeviewSubtitle->getSelected();
 	if(!iter_select)
@@ -942,37 +1011,37 @@ void SubtitleEditor::on_insert_after_subtitle()
 		time_end = time_start + SubtitleTime(0,0,2,0);
 	
 	Gtk::TreeIter new_iter = getDocument()->m_subtitleModel->insertAfter(iter_select);
-	m_treeviewSubtitle->select_and_set_cursor(new_iter);
 	
-	(*new_iter)[m_column.start]	= time_start.str();
-	(*new_iter)[m_column.end]		= time_end.str();
+	SubtitleModifier ni(new_iter);
+
+	ni.set_start(time_start);
+	ni.set_end(time_end);
+
+	getSubtitleView()->select_and_set_cursor(new_iter);
 }
 
+
 /*
  *
  */
 void SubtitleEditor::on_delete_subtitle()
 {
-	debug_msg("SubtitleEditor::on_delete_subtitle");
+	se_debug(SE_DEBUG_APP);
 
-	Gtk::TreeIter iter_select = m_treeviewSubtitle->getSelected();
-	if(!iter_select)
-		return;
-	
-	Gtk::TreeIter next = getDocument()->m_subtitleModel->find_next(iter_select);
-	Gtk::TreeIter prev = getDocument()->m_subtitleModel->find_previous(iter_select);
+	std::vector<Gtk::TreeModel::Path> rows = getSubtitleView()->get_selection()->get_selected_rows();
 
-
-	getDocument()->m_subtitleModel->remove(iter_select);
-
-	// select next line
-	if(next)
+	if(rows.size() > 0)
 	{
-		m_treeviewSubtitle->select_and_set_cursor(next);
-	}
-	else if(prev)
-	{
-		m_treeviewSubtitle->select_and_set_cursor(prev);
+		Glib::RefPtr<Gtk::TreeSelection> selection = getSubtitleView()->get_selection();
+
+		Glib::RefPtr<SubtitleModel> model = getDocument()->get_subtitle_model();
+
+		while((rows = selection->get_selected_rows()).size() > 0)
+		{
+			model->erase(model->get_iter(rows[0]));
+		}
+
+		model->rebuild_column_num();
 	}
 }
 
@@ -981,7 +1050,7 @@ void SubtitleEditor::on_delete_subtitle()
  */
 void SubtitleEditor::on_change_fps()
 {
-	debug_msg("SubtitleEditor::on_change_fps");
+	se_debug(SE_DEBUG_APP);
 
 	create_dialog("dialog-change-fps", &m_dialogChangeFPS);
 
@@ -993,7 +1062,7 @@ void SubtitleEditor::on_change_fps()
  */
 void SubtitleEditor::on_scale()
 {
-	debug_msg("SubtitleEditor::on_scale");
+	se_debug(SE_DEBUG_APP);
 
 	create_dialog("dialog-scale", &m_dialogScale);
 	
@@ -1007,11 +1076,10 @@ void SubtitleEditor::on_scale()
  */
 void SubtitleEditor::on_find()
 {
-	debug_msg("SubtitleEditor::on_find");
+	se_debug(SE_DEBUG_APP);
 
 	create_dialog("dialog-find-and-replace", &m_dialogFindAndReplace);
 	
-	m_dialogFindAndReplace->show_replace(false);
 	m_dialogFindAndReplace->execute();
 }
 
@@ -1020,7 +1088,7 @@ void SubtitleEditor::on_find()
  */
 void SubtitleEditor::on_find_next()
 {
-	debug_msg("SubtitleEditor::on_find_next");
+	se_debug(SE_DEBUG_APP);
 
 	if(m_dialogFindAndReplace == NULL)
 	{
@@ -1067,12 +1135,15 @@ bool find_and_replace2(Glib::ustring &source,
  */
 void SubtitleEditor::on_find_and_replace()
 {
-	debug_msg("SubtitleEditor::on_find_and_replace");
-	
+	se_debug(SE_DEBUG_APP);
+
+	DialogFindAndReplace *m_dialogFindAndReplace = NULL;
+
 	create_dialog("dialog-find-and-replace", &m_dialogFindAndReplace);
 
-	m_dialogFindAndReplace->show_replace(true);
 	m_dialogFindAndReplace->execute();
+
+	delete m_dialogFindAndReplace;
 }
 
 
@@ -1081,7 +1152,7 @@ void SubtitleEditor::on_find_and_replace()
  */
 void SubtitleEditor::on_remove_line_nul()
 {
-	debug_msg("SubtitleEditor::on_remove_line_nul");
+	se_debug(SE_DEBUG_APP);
 
 	SubtitleColumnRecorder m_column;
 	Glib::ustring text;
@@ -1106,7 +1177,7 @@ void SubtitleEditor::on_remove_line_nul()
  */
 void SubtitleEditor::on_check_time()
 {
-	debug_msg("SubtitleEditor::on_check_time");
+	se_debug(SE_DEBUG_APP);
 
 	SubtitleColumnRecorder m_column;
 
@@ -1138,7 +1209,6 @@ void SubtitleEditor::on_check_time()
 		if(start < prev_start)
 		{
 			m_treeviewSubtitle->select_and_set_cursor(iter);
-			//setStatusbar(_("Check Time : This subtitle starts before the starts of the preceding subtitle"));
 			setStatusbar(_("Check Time : Overlapping with previous subtitle"));
 			return;
 		}
@@ -1146,7 +1216,6 @@ void SubtitleEditor::on_check_time()
 		if(start < prev_end)
 		{
 			m_treeviewSubtitle->select_and_set_cursor(iter);
-			//setStatusbar(_("Check Time : This subtitle starts before the end of the preceding subtitle"));
 			setStatusbar(_("Check Time : Overlapping with previous subtitle"));
 			return;
 		}
@@ -1163,19 +1232,19 @@ void SubtitleEditor::on_check_time()
  */
 void SubtitleEditor::on_spell_check()
 {
-#ifdef ENABLE_ASPELL
+	se_debug(SE_DEBUG_APP);
 
-	debug_msg("SubtitleEditor::on_spell_check");
+#ifdef HAVE_ENCHANT_SUPPORT
 
-	DialogSpellCheck *spell = NULL;
+	DialogSpellChecking *spell = NULL;
 
-	create_dialog("dialog-spell-check", &spell);
+	create_dialog("dialog-spell-checking", &spell);
+
+	spell->execute();
 
-	spell->init(getDocument());
-	
 	delete spell;
 
-#endif//ENABLE_ASPELL
+#endif//HAVE_ENCHANT_SUPPORT
 }
 
 /*
@@ -1183,7 +1252,7 @@ void SubtitleEditor::on_spell_check()
  */
 void SubtitleEditor::on_set_all_end_time()
 {
-	debug_msg("SubtitleEditor::on_set_all_end_time");
+	se_debug(SE_DEBUG_APP);
 
 	m_dialogSetAllEndTime.show();
 
@@ -1197,11 +1266,10 @@ void SubtitleEditor::on_set_all_end_time()
 		{
 			for(; it; ++it)
 			{
-				SubtitleTime it_time_end((*it)[m_column.end]);
+				SubtitleModifier subtitle(it);
+
+				SubtitleTime it_time_end = subtitle.get_end() + time;
 
-				it_time_end = it_time_end + time;
-				(*it)[m_column.end] = it_time_end.str();
-				
 				// verification il n'est pas trop long avec le prochain st
 				Gtk::TreeIter it_next = getDocument()->m_subtitleModel->find_next(it);
 				if(it_next)
@@ -1215,17 +1283,18 @@ void SubtitleEditor::on_set_all_end_time()
 				}
 	
 				// mise a jour
-				(*it)[m_column.end] = it_time_end.str();
+				subtitle.set_end(it_time_end);
 			}
 		}
 		else // SET
 		{
 			for(; it; ++it)
 			{
-				SubtitleTime it_time_end((*it)[m_column.start]);
+				SubtitleModifier subtitle(it);
+
+				SubtitleTime it_time_end = subtitle.get_start();
 
 				it_time_end = it_time_end + time;
-				(*it)[m_column.end] = it_time_end.str();
 				
 				// verification il n'est pas trop long avec le prochain st
 				Gtk::TreeIter it_next = getDocument()->m_subtitleModel->find_next(it);
@@ -1240,7 +1309,7 @@ void SubtitleEditor::on_set_all_end_time()
 				}
 	
 				// mise a jour
-				(*it)[m_column.end] = it_time_end.str();
+				subtitle.set_end(it_time_end);
 			}
 		}
 	}
@@ -1249,53 +1318,12 @@ void SubtitleEditor::on_set_all_end_time()
 	
 }
 
-/*
- *	verifie dans une table des erreurs d'encodings.
- */
-void SubtitleEditor::on_check_error_encoding()
-{
-	debug_msg("SubtitleEditor::on_check_error_encoding");
-
-	gchar* array[][2]={
-		{"\302\234", "oe"},
-		{"\302\222", "'"},
-		{"\302\205", "."}, // ??
-		{NULL,NULL}};
-
-	SubtitleColumnRecorder m_column;
-
-	bool state=false;
-
-	Gtk::TreeIter iter = getDocument()->m_subtitleModel->getFirst();
-	for(; iter; ++iter)
-	{
-		state = false;
-		
-		Glib::ustring text = (*iter)[m_column.text];
-		
-		for(unsigned int i=0; array[i][0] != NULL; ++i)
-		{
-			if(find_and_replace2(text, array[i][0], array[i][1]))
-			{
-				state = true;
-			}
-		}
-
-		if(state)
-		{
-			(*iter)[m_column.text] = text;
-		}
-
-	}
-}
-
-
 /*
  *
  */
 void SubtitleEditor::on_about()
 {
-	debug_msg("SubtitleEditor::on_about");
+	se_debug(SE_DEBUG_APP);
 
 	DialogAbout about;
 	about.run();
@@ -1306,7 +1334,7 @@ void SubtitleEditor::on_about()
  */
 void SubtitleEditor::on_style_editor()
 {
-	debug_msg("SubtitleEditor::on_style_editor");
+	se_debug(SE_DEBUG_APP);
 
 	DialogStyleEditor* m_dialogStyleEditor = NULL;
 
@@ -1323,7 +1351,7 @@ void SubtitleEditor::on_style_editor()
  */
 void SubtitleEditor::on_preferences()
 {
-	debug_msg("SubtitleEditor::on_preferences");
+	se_debug(SE_DEBUG_APP);
 
 	DialogPreferences* m_dialogPreferences = NULL;
 
@@ -1340,23 +1368,28 @@ void SubtitleEditor::on_preferences()
  */
 void SubtitleEditor::on_apply_translation()
 {
-	SubtitleColumnRecorder m_column;
-
+	se_debug(SE_DEBUG_APP);
+	
 	Gtk::TreeIter iter = getDocument()->m_subtitleModel->getFirst();
 	for(; iter; ++iter)
 	{
-		Glib::ustring translation = (*iter)[m_column.translation];
+		SubtitleModifier subtitle(iter);
+
+		Glib::ustring translation = subtitle.get_translation();
 		
 		if(!translation.empty())
-			(*iter)[m_column.text] = translation;
+			subtitle.set_text(translation);
 	}
 
 	setStatusbar(_("The translation was applied."));
 }
 
+/*
+ *
+ */
 void SubtitleEditor::on_split()
 {
-	debug_msg("SubtitleEditor::on_split");
+	se_debug(SE_DEBUG_APP);
 
 	DialogSplit* m_dialogSplit= NULL;
 
@@ -1370,6 +1403,8 @@ void SubtitleEditor::on_split()
 
 void SubtitleEditor::on_joint()
 {
+	se_debug(SE_DEBUG_APP);
+	
 	DialogOpenSubtitle dialog;
 	if(dialog.run() == Gtk::RESPONSE_OK)
 	{
@@ -1396,7 +1431,7 @@ void SubtitleEditor::on_joint()
 template<class T>
 bool SubtitleEditor::create_dialog(const Glib::ustring &name, T **dialog)
 {
-	debug_msg(message("create_dialog %s", name.c_str()));
+	se_debug_message(SE_DEBUG_APP, "create %s", name.c_str());
 
 	if(*dialog == NULL)
 	{
@@ -1410,3 +1445,45 @@ bool SubtitleEditor::create_dialog(const Glib::ustring &name, T **dialog)
 	return true;
 }
 
+/*
+ *
+ */
+void SubtitleEditor::on_move_subtitle_text_forward()
+{
+	se_debug(SE_DEBUG_APP);
+
+	Gtk::TreeIter it = getSubtitleView()->getSelected();
+	if(it)
+	{
+		// recupere tous le textes des sous-titres a partir de la selection
+		std::vector<Glib::ustring> strings;
+
+		for(Gtk::TreeIter it2=it; it2; ++it2)
+			strings.push_back(SubtitleModifier(it2).get_text());
+
+		// on avance
+		SubtitleModifier(it).set_text("");
+
+		++it;
+
+		// on applique les modifications avec un decalage
+		for(unsigned int i=0; it; ++it, ++i)
+		{
+			SubtitleModifier(it).set_text(strings[i]);
+		}
+
+		// ajoute le derniers
+		Gtk::TreeIter last = getDocument()->get_subtitle_model()->append();
+
+		SubtitleModifier(last).set_text(strings.back());
+	}
+}
+
+/*
+ *
+ */
+void SubtitleEditor::on_move_subtitle_text_backward()
+{
+	se_debug(SE_DEBUG_APP);
+}
+
