@@ -50,9 +50,6 @@ public:
 	 *
 	 */
 	bool save(const Glib::ustring &filename, const Glib::ustring &encoding);
-
-protected:
-	Glib::RefPtr<SubtitleModel> m_subtitleModel;
 };
 
 #endif//_SubtitleText_h
