@@ -33,15 +33,173 @@
 #include "SubtitleView.h"
 #include "utility.h"
 #include <gtkmm/cellrenderercombo.h>
+#include <gtkmm/tooltips.h>
+#include <gtkmm/label.h>
+#include <gtkmm/eventbox.h>
 #include <gdk/gdkkeysyms.h>
 
+#include <gtkmm/textview.h>
+#include <gtkmm/celleditable.h>
+
 #include "Config.h"
 #include "ISubtitleEditor.h"
+#include "debug.h"
+
+/*
+ *	une CellEditable deriver de TextView qui permet d'avoir plusieur ligne
+ *	contrairement a GtkEntry (par defaut)
+ */
+class TextViewCell : public Gtk::TextView, public Gtk::CellEditable
+{
+public:
+	/*
+	 *
+	 */
+	TextViewCell(const Glib::ustring &path)
+	:
+		Glib::ObjectBase(typeid(TextViewCell)),
+		//Gtk::TextView(),
+		Gtk::CellEditable(),
+		m_path(path)
+	{
+		SE::getInstance()->setStatusbar(_("Use Ctrl+Return for line-break"));
+	}
+
+	/*
+	 *
+	 */
+	void do_editing_done()
+	{
+		remove_widget();
+		SE::getInstance()->setStatusbar("");
+	}
+
+	/*
+	 *
+	 */
+	Glib::ustring get_text() 
+	{
+		Glib::RefPtr<Gtk::TextBuffer> buffer = get_buffer();
+
+		Gtk::TextBuffer::iterator start, end;
+
+		buffer->get_bounds(start,end);
+		return buffer->get_text(start,end);
+	}
+
+	/*
+	 *
+	 */
+	void set_text(const Glib::ustring &text)
+	{
+		get_buffer()->set_text(text);
+	}
+
+	/*
+	 *
+	 */
+	bool on_key_press_event(GdkEventKey* event)
+	{
+		if(event->keyval == GDK_Escape)
+		{
+			editing_done();
+			remove_widget();
+			return true;
+		}
+		else if( (
+				 event->keyval == GDK_Return ||  
+				 event->keyval == GDK_KP_Enter ||  
+				 event->keyval == GDK_ISO_Enter ||  
+				 event->keyval == GDK_3270_Enter 
+				)	&& !(event->state & GDK_CONTROL_MASK))
+		{
+			m_signal_edited(m_path, get_text());
+			editing_done();
+			remove_widget();
+			return true;
+		}
+
+		return Gtk::TextView::on_key_press_event(event);
+	}
+	
+	/*
+	 *
+	 */
+	typedef sigc::signal<void,const Glib::ustring &, const Glib::ustring &> SignalEdited;
+
+	/*
+	 *
+	 */
+	SignalEdited& signal_edited()
+	{
+		return m_signal_edited;
+	}
+
+protected:
+	Glib::ustring m_path;
+	SignalEdited m_signal_edited;
+};
 
 
+/*
+ *	derive simplement de CellRendererText pour pouvoir utiliser
+ *	TextViewCell a l'edition.
+ */
+class CellRendererTextMultiline : public Gtk::CellRendererText
+{
+public:
+	/*
+	 *
+	 */
+	CellRendererTextMultiline()
+	:
+		Glib::ObjectBase(typeid(CellRendererTextMultiline)),
+		Gtk::CellRendererText(),
+		m_textViewCell(NULL)
+	{
+	}
+	
+	/*
+	 *
+	 */
+	virtual Gtk::CellEditable* start_editing_vfunc(
+			GdkEvent* event, 
+			Gtk::Widget &widget, 
+			const Glib::ustring &path, 
+			const Gdk::Rectangle& background_area,
+			const Gdk::Rectangle& cell_area,
+			Gtk::CellRendererState flags)
+	{
+		if(!property_editable())
+			return 0;
+
+		m_textViewCell = manage(new TextViewCell(path));
+		m_textViewCell->set_wrap_mode(Gtk::WRAP_NONE);
+		m_textViewCell->set_text(property_text());
+
+		m_textViewCell->signal_edited().connect(
+				sigc::mem_fun(*this, &CellRendererTextMultiline::edited));
+		
+		m_textViewCell->grab_focus();
+		
+		m_textViewCell->show();
+
+		return m_textViewCell;
+	}
+
+protected:
+	TextViewCell* m_textViewCell;
+
+};
+
+/*
+ *
+ */
 SubtitleView::SubtitleView(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
 :Gtk::TreeView(cobject)
 {
+	se_debug(SE_DEBUG_VIEW);
+
 	m_refDocument = SE::getInstance()->getDocument();
 		
 	set_model(m_refDocument->m_subtitleModel);
@@ -53,6 +211,7 @@ SubtitleView::SubtitleView(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Gl
 	createColumnLayer();
 	createColumnStart();
 	createColumnEnd();
+	createColumnDuration();
 	createColumnStyle();
 	createColumnName();
 	
@@ -63,6 +222,8 @@ SubtitleView::SubtitleView(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Gl
 	createColumnEffect();
 
 	createColumnText();
+	createColumnCharactersPerLine();
+
 	createColumnTranslation();
 
 	set_rules_hint(true);
@@ -72,14 +233,27 @@ SubtitleView::SubtitleView(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Gl
 
 	// config
 	loadCfg();
+	// je le place ici parceque dans le destructeur il y a un segfault!
 	saveCfg();
 
 	get_selection()->signal_changed().connect(
 			sigc::mem_fun(*this, &SubtitleView::on_selection_changed));
+
+	get_selection()->set_mode(Gtk::SELECTION_MULTIPLE);
 }
 
+SubtitleView::~SubtitleView()
+{
+	//saveCfg();
+}
+
+/*
+ *
+ */
 void SubtitleView::loadCfg()
 {
+	se_debug(SE_DEBUG_VIEW);
+
 	bool state = false;
 	
 	Config &cfg = Config::getInstance();
@@ -90,6 +264,7 @@ void SubtitleView::loadCfg()
 	SET("layer");
 	SET("start");
 	SET("end");
+	SET("duration");
 	SET("style");
 	SET("name");
 	SET("margin-l");
@@ -98,12 +273,18 @@ void SubtitleView::loadCfg()
 	SET("effect");
 	SET("text");
 	SET("translation");
+	SET("characters-per-line");
 	
 #undef SET
 }
 
+/*
+ *
+ */
 void SubtitleView::saveCfg()
 {
+	se_debug(SE_DEBUG_VIEW);
+
 	Config &cfg = Config::getInstance();
 
 #define SET(name)	cfg.set_value_bool("setup-view", "show-column-"name, get_column_visible(name));
@@ -112,6 +293,7 @@ void SubtitleView::saveCfg()
 	SET("layer");
 	SET("start");
 	SET("end");
+	SET("duration");
 	SET("style");
 	SET("name");
 	SET("margin-l");
@@ -120,15 +302,38 @@ void SubtitleView::saveCfg()
 	SET("effect");
 	SET("text");
 	SET("translation");
+	SET("characters-per-line");
 	
 #undef SET
 }
 
+/*
+ *
+ */
+void SubtitleView::set_tooltips(Gtk::TreeViewColumn *column, const Glib::ustring &text)
+{
+	se_debug_message(SE_DEBUG_VIEW, "[%s]=%s", column->get_title().c_str(), text.c_str());
+
+	Gtk::EventBox *event = manage(new Gtk::EventBox);
+
+	Gtk::Label* label = manage(new Gtk::Label(column->get_title()));
+	event->add(*label);
+
+	Gtk::Tooltips *tooltips = manage(new Gtk::Tooltips);
+	tooltips->set_tip(*event, text);
+	tooltips->enable();
+
+	column->set_widget(*event);
+	event->show_all();
+}
+
 /*
  *	create columns
  */
 void SubtitleView::createColumnNum()
 {
+	se_debug(SE_DEBUG_VIEW);
+
 	Gtk::TreeViewColumn* column = NULL;
 	Gtk::CellRendererText* renderer = NULL;
 	
@@ -141,8 +346,11 @@ void SubtitleView::createColumnNum()
 	append_column(*column);
 	//append_column_numeric_editable("num", m_column.num, "%d");
 	renderer->property_editable() = false;
+	renderer->property_yalign() = 0;
 
 	m_columns["number"] = column;
+
+	set_tooltips(column, _("This number column"));
 }
 
 /*
@@ -150,6 +358,8 @@ void SubtitleView::createColumnNum()
  */
 void SubtitleView::createColumnLayer()
 {
+	se_debug(SE_DEBUG_VIEW);
+
 	Gtk::TreeViewColumn* column = NULL;
 	Gtk::CellRendererText* renderer = NULL;
 	
@@ -160,12 +370,16 @@ void SubtitleView::createColumnLayer()
 	column->add_attribute(renderer->property_text(), m_column.layer);
 
 	renderer->property_editable() = true;
+	renderer->property_yalign() = 0;
+
 	renderer->signal_edited().connect(
 		sigc::mem_fun(*this, &SubtitleView::on_edited_layer));
 
 	append_column(*column);
 
 	m_columns["layer"] = column;
+
+	set_tooltips(column, _("Layer number."));
 }
 
 /*
@@ -173,6 +387,8 @@ void SubtitleView::createColumnLayer()
  */
 void SubtitleView::createColumnStart()
 {
+	se_debug(SE_DEBUG_VIEW);
+
 	Gtk::TreeViewColumn* column = NULL;
 	Gtk::CellRendererText* renderer = NULL;
 	
@@ -183,12 +399,16 @@ void SubtitleView::createColumnStart()
 	column->add_attribute(renderer->property_text(), m_column.start);
 	
 	renderer->property_editable() = true;
+	renderer->property_yalign() = 0;
+
 	renderer->signal_edited().connect(
 		sigc::mem_fun(*this, &SubtitleView::on_edited_start));
 
 	append_column(*column);
 
 	m_columns["start"] = column;
+
+	set_tooltips(column, _("This time is the time when a subtitle appears on the screen."));
 }
 
 /*
@@ -196,6 +416,8 @@ void SubtitleView::createColumnStart()
  */
 void SubtitleView::createColumnEnd()
 {
+	se_debug(SE_DEBUG_VIEW);
+
 	Gtk::TreeViewColumn* column = NULL;
 	Gtk::CellRendererText* renderer = NULL;
 	
@@ -206,12 +428,45 @@ void SubtitleView::createColumnEnd()
 	column->add_attribute(renderer->property_text(), m_column.end);
 	
 	renderer->property_editable() = true;
+	renderer->property_yalign() = 0;
+
 	renderer->signal_edited().connect(
 		sigc::mem_fun(*this, &SubtitleView::on_edited_end));
 
 	append_column(*column);
 
 	m_columns["end"] = column;
+
+	set_tooltips(column, _("This time is the time when a subtitle disappears from the screen."));
+}
+
+/*
+ *
+ */
+void SubtitleView::createColumnDuration()
+{
+	se_debug(SE_DEBUG_VIEW);
+
+	Gtk::TreeViewColumn* column = NULL;
+	Gtk::CellRendererText* renderer = NULL;
+	
+	column = manage(new Gtk::TreeViewColumn(_("duration")));
+	renderer = manage(new Gtk::CellRendererText);
+	
+	column->pack_start(*renderer, false);
+	column->add_attribute(renderer->property_text(), m_column.duration);
+	
+	renderer->property_editable() = true;
+	renderer->property_yalign() = 0;
+
+	renderer->signal_edited().connect(
+		sigc::mem_fun(*this, &SubtitleView::on_edited_duration));
+
+	append_column(*column);
+
+	m_columns["duration"] = column;
+#warning "FIXME tooltip duration"
+	set_tooltips(column, _("This time is the duration..."));
 }
 
 /*
@@ -219,6 +474,8 @@ void SubtitleView::createColumnEnd()
  */
 void SubtitleView::createColumnStyle()
 {
+	se_debug(SE_DEBUG_VIEW);
+
 	Gtk::TreeViewColumn* column = NULL;
 	Gtk::CellRendererCombo* renderer = NULL;
 	
@@ -232,6 +489,7 @@ void SubtitleView::createColumnStyle()
 	renderer->property_text_column() = 0;
 	renderer->property_editable() = true;
 	renderer->property_has_entry() = false;
+	renderer->property_yalign() = 0;
 	
 	renderer->signal_edited().connect(
 		sigc::mem_fun(*this, &SubtitleView::on_edited_style));
@@ -246,6 +504,8 @@ void SubtitleView::createColumnStyle()
  */
 void SubtitleView::createColumnName()
 {
+	se_debug(SE_DEBUG_VIEW);
+
 	Gtk::TreeViewColumn* column = NULL;
 	Gtk::CellRendererText* renderer = NULL;
 	
@@ -256,6 +516,7 @@ void SubtitleView::createColumnName()
 	column->add_attribute(renderer->property_text(), m_column.name);
 	
 	renderer->property_editable() = true;
+	renderer->property_yalign() = 0;
 
 	renderer->signal_edited().connect(
 		sigc::mem_fun(*this, &SubtitleView::on_edited_name));
@@ -270,18 +531,23 @@ void SubtitleView::createColumnName()
  */
 void SubtitleView::createColumnText()
 {
+	se_debug(SE_DEBUG_VIEW);
+
 	Gtk::TreeViewColumn* column = NULL;
-	Gtk::CellRendererText* renderer = NULL;
-	
+	//Gtk::CellRendererText* renderer = NULL;
+	CellRendererTextMultiline* renderer = NULL;
 	column = manage(new Gtk::TreeViewColumn(_("text")));
-	renderer = manage(new Gtk::CellRendererText);
+	//renderer = manage(new Gtk::CellRendererText);
+	renderer = manage(new CellRendererTextMultiline);//manage(new Gtk::CellRendererText);
 	
-	column->pack_start(*renderer, false);
+	column->pack_start(*renderer, true);//false);
 	column->add_attribute(renderer->property_text(), m_column.text);
 	
 	append_column(*column);
 	
 	renderer->property_editable() = true;
+	renderer->property_yalign() = 0;
+
 	renderer->signal_edited().connect(
 		sigc::mem_fun(*this, &SubtitleView::on_edited_text));
 
@@ -299,11 +565,13 @@ void SubtitleView::createColumnText()
  */
 void SubtitleView::createColumnTranslation()
 {
+	se_debug(SE_DEBUG_VIEW);
+
 	Gtk::TreeViewColumn* column = NULL;
 	Gtk::CellRendererText* renderer = NULL;
 	
 	column = manage(new Gtk::TreeViewColumn(_("translation")));
-	renderer = manage(new Gtk::CellRendererText);
+	renderer = manage(new CellRendererTextMultiline);
 	
 	column->pack_start(*renderer, false);
 	column->add_attribute(renderer->property_text(), m_column.translation);
@@ -311,6 +579,8 @@ void SubtitleView::createColumnTranslation()
 	append_column(*column);
 	
 	renderer->property_editable() = true;
+	renderer->property_yalign() = 0;
+
 	renderer->signal_edited().connect(
 		sigc::mem_fun(*this, &SubtitleView::on_edited_translation));
 
@@ -325,6 +595,8 @@ void SubtitleView::createColumnTranslation()
  */
 void SubtitleView::createColumnEffect()
 {
+	se_debug(SE_DEBUG_VIEW);
+
 	Gtk::TreeViewColumn* column = NULL;
 	Gtk::CellRendererText* renderer = NULL;
 	
@@ -337,6 +609,8 @@ void SubtitleView::createColumnEffect()
 	append_column(*column);
 	
 	renderer->property_editable() = true;
+	renderer->property_yalign() = 0;
+
 	renderer->signal_edited().connect(
 		sigc::mem_fun(*this, &SubtitleView::on_edited_effect));
 
@@ -351,6 +625,8 @@ void SubtitleView::createColumnEffect()
  */
 void SubtitleView::createColumnMarginR()
 {
+	se_debug(SE_DEBUG_VIEW);
+
 	Gtk::TreeViewColumn* column = NULL;
 	Gtk::CellRendererText* renderer = NULL;
 	
@@ -361,6 +637,7 @@ void SubtitleView::createColumnMarginR()
 	column->add_attribute(renderer->property_text(), m_column.marginR);
 	
 	renderer->property_editable() = true;
+	renderer->property_yalign() = 0;
 
 	renderer->signal_edited().connect(
 		sigc::mem_fun(*this, &SubtitleView::on_edited_margin_r));
@@ -375,6 +652,8 @@ void SubtitleView::createColumnMarginR()
  */
 void SubtitleView::createColumnMarginL()
 {
+	se_debug(SE_DEBUG_VIEW);
+
 	Gtk::TreeViewColumn* column = NULL;
 	Gtk::CellRendererText* renderer = NULL;
 	
@@ -385,6 +664,7 @@ void SubtitleView::createColumnMarginL()
 	column->add_attribute(renderer->property_text(), m_column.marginL);
 	
 	renderer->property_editable() = true;
+	renderer->property_yalign() = 0;
 
 	renderer->signal_edited().connect(
 		sigc::mem_fun(*this, &SubtitleView::on_edited_margin_l));
@@ -399,6 +679,8 @@ void SubtitleView::createColumnMarginL()
  */
 void SubtitleView::createColumnMarginV()
 {
+	se_debug(SE_DEBUG_VIEW);
+
 	Gtk::TreeViewColumn* column = NULL;
 	Gtk::CellRendererText* renderer = NULL;
 	
@@ -409,6 +691,7 @@ void SubtitleView::createColumnMarginV()
 	column->add_attribute(renderer->property_text(), m_column.marginV);
 	
 	renderer->property_editable() = true;
+	renderer->property_yalign() = 0;
 
 	renderer->signal_edited().connect(
 		sigc::mem_fun(*this, &SubtitleView::on_edited_margin_v));
@@ -418,12 +701,52 @@ void SubtitleView::createColumnMarginV()
 	m_columns["margin-v"] = column;
 }
 
+/*
+ *
+ */
+void SubtitleView::createColumnCharactersPerLine()
+{
+	se_debug(SE_DEBUG_VIEW);
+
+	Gtk::TreeViewColumn* column = NULL;
+	Gtk::CellRendererText* renderer = NULL;
+	
+	column = manage(new Gtk::TreeViewColumn(_("cpl")));
+	renderer = manage(new Gtk::CellRendererText);
+	
+	column->pack_end(*renderer, false);
+	column->add_attribute(renderer->property_text(), m_column.characters_per_line);
+	
+	//renderer->property_editable() = true;
+	renderer->property_yalign() = 0;
+	//renderer->signal_edited().connect(
+	//	sigc::mem_fun(*this, &SubtitleView::on_edited_));
+
+	append_column(*column);
+
+	m_columns["characters-per-line"] = column;
+
+	set_tooltips(column, _("This column represents the number of characters per line."));
+}
+
 /*
  *	retourne l'item select ou NULL
  */
 Gtk::TreeIter SubtitleView::getSelected()
 {
-	return get_selection()->get_selected();
+	se_debug(SE_DEBUG_VIEW);
+	
+	Glib::RefPtr<Gtk::TreeSelection> selection = get_selection();
+	
+	std::vector<Gtk::TreeModel::Path> rows = selection->get_selected_rows();
+
+	if(rows.size() > 0)
+	{
+		return selection->get_model()->get_iter(rows[0]);
+	}
+
+	Gtk::TreeIter null;
+	return null;
 }
 
 /*
@@ -431,6 +754,8 @@ Gtk::TreeIter SubtitleView::getSelected()
  */
 void SubtitleView::on_selection_changed()
 {
+	se_debug(SE_DEBUG_VIEW);
+
 	Signal::getInstance().subtitle_view_selection_changed(getSelected());
 }
 
@@ -439,12 +764,14 @@ void SubtitleView::on_selection_changed()
  */
 void SubtitleView::on_edited_layer( const Glib::ustring &path, const Glib::ustring &value)
 {
-	Gtk::TreeIter iter = m_subtitleModel->get_iter(path);
-	if(iter)
+	se_debug_message(SE_DEBUG_VIEW, "%s %s", path.c_str(), value.c_str());
+
+	SubtitleModifier subtitle(m_subtitleModel->get_iter(path));
+	if(subtitle)
 	{
-		int val = 0;
+		unsigned int val = 0;
 		if(from_string(value, val))
-			(*iter)[m_column.layer] = value;
+			subtitle.set_layer(value);
 	}
 }
 
@@ -455,19 +782,16 @@ void SubtitleView::on_edited_layer( const Glib::ustring &path, const Glib::ustri
 void SubtitleView::on_edited_start( const Glib::ustring &path, 
 																		const Glib::ustring &newtext)
 {
-	Gtk::TreeIter iter = m_subtitleModel->get_iter(path);
-	if(iter)
+	se_debug_message(SE_DEBUG_VIEW, "%s %s", path.c_str(), newtext.c_str());
+
+	SubtitleModifier subtitle(m_subtitleModel->get_iter(path));
+	if(subtitle)
 	{
 		if(SubtitleTime::validate(newtext))
 		{
-			SubtitleTime time(newtext);
-
-			// ici on convertir en MSecs pour ensuite le reconvertir en temps normal (h,m,s,ms)
-			// afin de pouvoir recevoir des chiffres "bizarre" ex: "00:05:99,000" (99 secs est faux)
-			// il y aura donc une conversion ce qui va donner : "00:06:39,000"
-			(*iter)[m_column.start] = time.str();
+			subtitle.set_start(newtext);
 			
-			Signal::getInstance().subtitle_time_changed(iter);
+			Signal::getInstance().subtitle_time_changed(subtitle.get_iter());
 		}
 		else
 		{
@@ -482,19 +806,16 @@ void SubtitleView::on_edited_start( const Glib::ustring &path,
 void SubtitleView::on_edited_end( const Glib::ustring &path, 
 																	const Glib::ustring &newtext)
 {
-	Gtk::TreeIter iter = m_subtitleModel->get_iter(path);
-	if(iter)
+	se_debug_message(SE_DEBUG_VIEW, "%s %s", path.c_str(), newtext.c_str());
+
+	SubtitleModifier subtitle(m_subtitleModel->get_iter(path));
+	if(subtitle)
 	{
 		if(SubtitleTime::validate(newtext))
 		{
-			SubtitleTime time(newtext);
+			subtitle.set_end(newtext);
 
-			// ici on convertir en MSecs pour ensuite le reconvertir en temps normal (h,m,s,ms)
-			// afin de pouvoir recevoir des chiffres "bizarre" ex: "00:05:99,000" (99 secs et faux)
-			// il y aura donc une conversion ce qui va donner : "00:06:39,000"
-			(*iter)[m_column.end] = time.str();
-
-			Signal::getInstance().subtitle_time_changed(iter);
+			Signal::getInstance().subtitle_time_changed(subtitle.get_iter());
 		}
 		else
 		{
@@ -503,16 +824,41 @@ void SubtitleView::on_edited_end( const Glib::ustring &path,
 	}
 }
 
+/*
+ *	callback utiliser pour modifier le temps directement depuis la list (treeview)
+ */
+void SubtitleView::on_edited_duration( const Glib::ustring &path, 
+																	const Glib::ustring &newtext)
+{
+	se_debug_message(SE_DEBUG_VIEW, "%s %s", path.c_str(), newtext.c_str());
+
+	SubtitleModifier subtitle(m_subtitleModel->get_iter(path));
+	if(subtitle)
+	{
+		if(SubtitleTime::validate(newtext))
+		{
+			subtitle.set_duration(newtext);
+			Signal::getInstance().subtitle_time_changed(subtitle.get_iter());
+		}
+		else
+		{
+			std::cerr << "on_edited_duration::invalide> " << newtext << std::endl;
+		}
+	}
+}
+
 /*
  *	callback utiliser pour modifier le texte
  */
 void SubtitleView::on_edited_text( const Glib::ustring &path, 
 																		const Glib::ustring &newtext)
 {
-	Gtk::TreeIter iter = m_subtitleModel->get_iter(path);
-	if(iter)
+	se_debug_message(SE_DEBUG_VIEW, "%s %s", path.c_str(), newtext.c_str());
+
+	SubtitleModifier subtitle(m_subtitleModel->get_iter(path));
+	if(subtitle)
 	{
-		(*iter)[m_column.text] = newtext;
+		subtitle.set_text(newtext);
 	}
 }
 
@@ -522,10 +868,12 @@ void SubtitleView::on_edited_text( const Glib::ustring &path,
 void SubtitleView::on_edited_translation( const Glib::ustring &path, 
 																		const Glib::ustring &newtext)
 {
-	Gtk::TreeIter iter = m_subtitleModel->get_iter(path);
-	if(iter)
+	se_debug_message(SE_DEBUG_VIEW, "%s %s", path.c_str(), newtext.c_str());
+
+	SubtitleModifier subtitle(m_subtitleModel->get_iter(path));
+	if(subtitle)
 	{
-		(*iter)[m_column.translation] = newtext;
+		subtitle.set_translation(newtext);
 	}
 }
 
@@ -534,10 +882,12 @@ void SubtitleView::on_edited_translation( const Glib::ustring &path,
 void SubtitleView::on_edited_effect( const Glib::ustring &path, 
 																		const Glib::ustring &newtext)
 {
-	Gtk::TreeIter iter = m_subtitleModel->get_iter(path);
-	if(iter)
+	se_debug_message(SE_DEBUG_VIEW, "%s %s", path.c_str(), newtext.c_str());
+
+	SubtitleModifier subtitle(m_subtitleModel->get_iter(path));
+	if(subtitle)
 	{
-		(*iter)[m_column.effect] = newtext;
+		subtitle.set_effect(newtext);
 	}
 }
 
@@ -548,10 +898,12 @@ void SubtitleView::on_edited_effect( const Glib::ustring &path,
 void SubtitleView::on_edited_style( const Glib::ustring &path, 
 																		const Glib::ustring &newstyle)
 {
-	Gtk::TreeIter iter = m_subtitleModel->get_iter(path);
-	if(iter)
+	se_debug_message(SE_DEBUG_VIEW, "%s %s", path.c_str(), newstyle.c_str());
+
+	SubtitleModifier subtitle(m_subtitleModel->get_iter(path));
+	if(subtitle)
 	{
-		(*iter)[m_column.style] = newstyle;
+		subtitle.set_style(newstyle);
 	}
 }
 
@@ -561,10 +913,12 @@ void SubtitleView::on_edited_style( const Glib::ustring &path,
 void SubtitleView::on_edited_name( const Glib::ustring &path, 
 																		const Glib::ustring &newname)
 {
-	Gtk::TreeIter iter = m_subtitleModel->get_iter(path);
-	if(iter)
+	se_debug_message(SE_DEBUG_VIEW, "%s %s", path.c_str(), newname.c_str());
+
+	SubtitleModifier subtitle(m_subtitleModel->get_iter(path));
+	if(subtitle)
 	{
-		(*iter)[m_column.name] = newname;
+		subtitle.set_name(newname);
 	}
 }
 
@@ -573,12 +927,14 @@ void SubtitleView::on_edited_name( const Glib::ustring &path,
  */
 void SubtitleView::on_edited_margin_l( const Glib::ustring &path, const Glib::ustring &value)
 {
-	Gtk::TreeIter iter = m_subtitleModel->get_iter(path);
-	if(iter)
+	se_debug_message(SE_DEBUG_VIEW, "%s %s", path.c_str(), value.c_str());
+
+	SubtitleModifier subtitle(m_subtitleModel->get_iter(path));
+	if(subtitle)
 	{
-		int val = 0;
+		unsigned int val = 0;
 		if(from_string(value, val))
-			(*iter)[m_column.marginL] = value;
+			subtitle.set_margin_l(value);
 	}
 }
 
@@ -587,12 +943,14 @@ void SubtitleView::on_edited_margin_l( const Glib::ustring &path, const Glib::us
  */
 void SubtitleView::on_edited_margin_r( const Glib::ustring &path, const Glib::ustring &value)
 {
-	Gtk::TreeIter iter = m_subtitleModel->get_iter(path);
-	if(iter)
+	se_debug_message(SE_DEBUG_VIEW, "%s %s", path.c_str(), value.c_str());
+
+	SubtitleModifier subtitle(m_subtitleModel->get_iter(path));
+	if(subtitle)
 	{
-		int val = 0;
+		unsigned int val = 0;
 		if(from_string(value, val))
-			(*iter)[m_column.marginR] = value;
+			subtitle.set_margin_r(value);
 	}
 }
 
@@ -601,12 +959,14 @@ void SubtitleView::on_edited_margin_r( const Glib::ustring &path, const Glib::us
  */
 void SubtitleView::on_edited_margin_v( const Glib::ustring &path, const Glib::ustring &value)
 {
-	Gtk::TreeIter iter = m_subtitleModel->get_iter(path);
-	if(iter)
+	se_debug_message(SE_DEBUG_VIEW, "%s %s", path.c_str(), value.c_str());
+
+	SubtitleModifier subtitle(m_subtitleModel->get_iter(path));
+	if(subtitle)
 	{
-		int val = 0;
+		unsigned int val = 0;
 		if(from_string(value, val))
-			(*iter)[m_column.marginV] = value;
+			subtitle.set_margin_v(value);
 	}
 }
 
@@ -615,6 +975,8 @@ void SubtitleView::on_edited_margin_v( const Glib::ustring &path, const Glib::us
  */
 void SubtitleView::select_and_set_cursor(const Gtk::TreeIter &iter)
 {
+	se_debug(SE_DEBUG_VIEW);
+
 	get_selection()->select(iter);
 	set_cursor(m_subtitleModel->get_path(iter), *m_columns["text"], false);
 }
@@ -626,14 +988,18 @@ void SubtitleView::select_and_set_cursor(const Gtk::TreeIter &iter)
  *	afficher certaine colonne ou non
  *	"srt" ou "ssa"
  */
+
 void SubtitleView::set_view_type(const Glib::ustring &type)
 {
+	se_debug_message(SE_DEBUG_VIEW, "%s", type.c_str());
+
 	if(type == "srt")
 	{
 		m_columns["number"]->set_visible(true);
 		m_columns["layer"]->set_visible(false);
 		m_columns["start"]->set_visible(true);
 		m_columns["end"]->set_visible(true);
+		m_columns["duration"]->set_visible(true);
 		m_columns["style"]->set_visible(false);
 		m_columns["name"]->set_visible(false);
 		m_columns["margin-l"]->set_visible(false);
@@ -649,6 +1015,7 @@ void SubtitleView::set_view_type(const Glib::ustring &type)
 		m_columns["layer"]->set_visible(true);
 		m_columns["start"]->set_visible(true);
 		m_columns["end"]->set_visible(true);
+		m_columns["duration"]->set_visible(true);
 		m_columns["style"]->set_visible(true);
 		m_columns["name"]->set_visible(true);
 		m_columns["margin-l"]->set_visible(false);
@@ -662,11 +1029,14 @@ void SubtitleView::set_view_type(const Glib::ustring &type)
 		std::cerr << "SubtitleView::set_view_type type no found :" << type << std::endl;
 }
 
+
 /*
  *
  */
 void SubtitleView::set_column_visible(const Glib::ustring& name, bool state)
 {
+	se_debug_message(SE_DEBUG_VIEW, "%s=%s", name.c_str(), state ? "true" : "false");
+
 	std::map<Glib::ustring, Gtk::TreeViewColumn*>::iterator it = m_columns.find(name);
 	if(it == m_columns.end())
 	{
@@ -688,62 +1058,11 @@ bool SubtitleView::get_column_visible(const Glib::ustring &name)
 	std::map<Glib::ustring, Gtk::TreeViewColumn*>::iterator it = m_columns.find(name);
 	if(it == m_columns.end())
 	{
-		std::cerr << "SubtitleView::set_column_visible : " << name << " not found" << std::endl;
+		se_debug_message(SE_DEBUG_VIEW, "<%s> not found.", name.c_str());
 		return false;
 	}
 	
+	se_debug_message(SE_DEBUG_VIEW, "<%s> = %s", name.c_str(), it->second->get_visible() ? "true" : "false");
 	return it->second->get_visible();
 }
 
-/*
- *
- */
-/*
-bool SubtitleView::on_key_press_event(GdkEventKey *event)
-{
-	bool res = Gtk::TreeView::on_key_press_event(event);
-	return res;
-}
-
-#include <gtkmm/entry.h>
-
-Gtk::Entry *__entry = NULL;
-
-void SubtitleView::editing_start(Gtk::CellEditable* cell, const Glib::ustring &path)
-{
-	std::cout << "editing_start:" << path << std::endl;
-
-	Gtk::Entry* entry = static_cast<Gtk::Entry*>(cell);
-	if(entry != NULL)
-	{
-		__entry = entry;
-
-		entry->signal_key_press_event().connect(
-				sigc::mem_fun(*this, &SubtitleView::entry_key_press_event));
-
-		entry->grab_focus();
-	}
-}
-
-bool SubtitleView::entry_key_press_event(GdkEventKey *ev)
-{
-	std::cout << "entry_key_press_event" << std::endl;
-
-	guint state = ev->state;
-	guint keyval = ev->keyval;
-
-	if(state & GDK_CONTROL_MASK && keyval == GDK_Return)
-	{
-		Glib::ustring enter("\\n");
-		int position = __entry->get_position();
-
-		std::cout << "entrer" << std::endl;
-		__entry->insert_text(enter, enter.size(), position);
-
-		__entry->set_position(position + enter.size());
-		return false;
-	}
-	return true;
-}
-*/
-
