@@ -716,9 +716,8 @@ bool WaveformDrawingArea::on_button_press_event(GdkEventButton *ev)
 {
 	bool state = DrawingArea::on_button_press_event(ev);
 
-	Gtk::TreeIter it = SE::getInstance()->getSubtitleView()->getSelected();
+	SubtitleModifier subtitle(SE::getInstance()->getSubtitleView()->getSelected());
 
-	SubtitleColumnRecorder m_column;
 	// il faut prendre en compte la hscrollbar
 	guint x = (guint)ev->x + get_start_area();
 
@@ -726,9 +725,9 @@ bool WaveformDrawingArea::on_button_press_event(GdkEventButton *ev)
 	
 	Glib::ustring time_str = getTime2MSecs(time / GST_MSECOND).str();
 
-	if(ev->button == 1 && it)
+	if(ev->button == 1 && subtitle)
 	{
-		(*it)[m_column.start] = time_str;
+		subtitle.set_start(time_str);
 
 		queue_draw();
 	}
@@ -743,10 +742,9 @@ bool WaveformDrawingArea::on_button_press_event(GdkEventButton *ev)
 			m_media->play();
 		}
 	}
-	else if(ev->button == 3 && it)
+	else if(ev->button == 3 && subtitle)
 	{
-		(*it)[m_column.end] = time_str;
-
+		subtitle.set_end(time_str);
 		queue_draw();
 	}
 	
@@ -765,11 +763,10 @@ bool WaveformDrawingArea::on_motion_notify_event(GdkEventMotion *ev)
 {
 	bool state = DrawingArea::on_motion_notify_event(ev);
 
-	Gtk::TreeIter it = SE::getInstance()->getSubtitleView()->getSelected();
-	if(!it)
+	SubtitleModifier subtitle(SE::getInstance()->getSubtitleView()->getSelected());
+	if(!subtitle)
 		return state;
 
-	SubtitleColumnRecorder m_column;
 	// il faut prendre en compte la hscrollbar
 	gint x = (guint)ev->x + get_start_area();
 	
@@ -781,13 +778,13 @@ bool WaveformDrawingArea::on_motion_notify_event(GdkEventMotion *ev)
 
 	if(ev->state & Gdk::BUTTON1_MASK)
 	{
-		(*it)[m_column.end] = time_str;
+		subtitle.set_end(time_str);
 
 		queue_draw();
 	}
 	else if(ev->state & Gdk::BUTTON3_MASK)
 	{
-		(*it)[m_column.end] = time_str;
+		subtitle.set_end(time_str);
 
 		queue_draw();
 	}
@@ -1073,10 +1070,10 @@ void TimingSystem::play_subtitle(Gtk::TreeIter it)
 	if(!it)
 		return;
 
-	SubtitleColumnRecorder column;
+	SubtitleModifier subtitle(it);
 
-	SubtitleTime start((*it)[column.start]);
-	SubtitleTime end((*it)[column.end]);
+	SubtitleTime start = subtitle.get_start();
+	SubtitleTime end = subtitle.get_end();
 	
 	gint64 gst_start = start.totalmsecs * GST_MSECOND;
 	gint64 gst_end = end.totalmsecs * GST_MSECOND;
@@ -1170,10 +1167,10 @@ void TimingSystem::on_signal_subtitle_view_selection_changed(Gtk::TreeIter it)
 		int x = (int)m_scrollbarWavform->get_value();
 		int w = x + m_scrollbarWavform->get_allocation().get_width();
 		
-		SubtitleColumnRecorder m_column;
-		
-		SubtitleTime start((*it)[m_column.start]);
-		SubtitleTime end((*it)[m_column.end]);
+		SubtitleModifier subtitle(it);
+
+		SubtitleTime start = subtitle.get_start();
+		SubtitleTime end = subtitle.get_end();
 
 		gint64 s = start.totalmsecs * GST_MSECOND;
 		gint64 e = end.totalmsecs * GST_MSECOND;
