@@ -41,27 +41,40 @@
 #include <sstream>
 #include <iostream>
 
+#include "debug.h"
 
 
 #ifdef ENABLE_NLS
-#include <libintl.h>
-#define _(String) gettext(String)
-#ifdef gettext_noop
-#define N_(String) gettext_noop(String)
-#else
-#define N_(String) (String)
-#endif
+	#include <libintl.h>
+	#include <glib/gi18n.h>
+	/*
+	#define _(String) gettext(String)
+	#ifdef gettext_noop
+	#define N_(String) gettext_noop(String)
+	#else
+	#define N_(String) (String)
+	#endif
+	*/
 #else /* NLS is disabled */
-#define _(String) (String)
-#define N_(String) (String)
-#define textdomain(String) (String)
-#define gettext(String) (String)
-#define dgettext(Domain,String) (String)
-#define dcgettext(Domain,String,Type) (String)
-#define bindtextdomain(Domain,Directory) (Domain) 
-#define bind_textdomain_codeset(Domain,Codeset) (Codeset) 
+	#define _(String) (String)
+	#define N_(String) (String)
+	#define textdomain(String) (String)
+	#define gettext(String) (String)
+	#define dgettext(Domain,String) (String)
+	#define dcgettext(Domain,String,Type) (String)
+	#define bindtextdomain(Domain,Directory) (Domain) 
+	#define bind_textdomain_codeset(Domain,Codeset) (Codeset) 
 #endif /* ENABLE_NLS */
 
+
+/*
+ *
+ */
+Glib::ustring get_iso_name_for_lang_code(const Glib::ustring &code);
+
+/*
+ *
+ */
 void find_and_replace(Glib::ustring &text, const Glib::ustring &find, const Glib::ustring &replace);
 
 /*
@@ -75,6 +88,10 @@ Glib::ustring get_share_dir(const Glib::ustring &file);
  */
 Glib::ustring check_end_char(const Glib::ustring &str);
 
+/*
+ * "\n", "\r\n",... TODO
+ */
+Glib::ustring get_newline();
 
 /*
  *	convertir str en n'importe quel type
@@ -87,13 +104,13 @@ bool from_string(const std::string &src, T& dest)
 
 	bool state = s >> dest != 0;
 
-	g_return_val_if_fail(state, false);
-
-	return true;
+	//g_return_val_if_fail(state, false);
+	//return true;
+	return state;
 }
 
 /*
- *
+ *	convertir str en n'importe quel type
  */
 template<class T>
 bool from_string(const Glib::ustring &src, T& dest)
@@ -103,9 +120,9 @@ bool from_string(const Glib::ustring &src, T& dest)
 
 	bool state = s >> dest != 0;
 
-	g_return_val_if_fail(state, false);
-
-	return true;
+	//g_return_val_if_fail(state, false);
+	//return true;
+	return state;
 }
 
 /*
@@ -121,43 +138,15 @@ std::string to_string(const T &src)
 }
 
 
-void dialog_warning(const Glib::ustring &primary_text, const Glib::ustring &secondary_text);
-void dialog_error(const Glib::ustring &primary_text, const Glib::ustring &secondary_text);
-
-
-
 /*
- *	DEBUG
+ *
  */
-
-Glib::ustring message(const char *format, ...);
-
-void debug(const char *key, const Glib::ustring &msg);
-
-#ifdef DEBUG_MSG
-	#define debug_msg(msg) debug(__PRETTY_FUNCTION__, msg);
-#else//DEBUG_MSG
-	#define debug_msg(msg)
-#endif//DEBUG_MSG
-
-
-#include <regex.h>
+void dialog_warning(const Glib::ustring &primary_text, const Glib::ustring &secondary_text);
 
 /*
  *
  */
-class RegEx
-{
-public:
-	RegEx(const std::string &ex, int flag = REG_EXTENDED | REG_NEWLINE);
-	~RegEx();
+void dialog_error(const Glib::ustring &primary_text, const Glib::ustring &secondary_text);
 
-	bool exec(const std::string &string);
-	bool exec(const std::string &string, std::string::size_type &start, std::string::size_type &len);
-
-protected:
-	int m_err;
-	regex_t m_rx;
-};
 
 #endif//_utility_h
